@@ -5,7 +5,6 @@ use Scalar::Alias;
 
 my $x = 10;
 
-eval q{
 my alias($y, $z) = ($x, $x);
 
 $x += 10;
@@ -15,5 +14,4 @@ x = $x
 y = $y
 z = $z
 EOT
-}
 
